@@ -80,6 +80,9 @@ class Object:
         },
         "attributes": {
           ...
+        },
+        "meta": {
+          ...
         }
       }
 
@@ -105,6 +108,9 @@ class Object:
     if 'relationships' in obj_dict:
       obj._relationships = obj_dict['relationships']
 
+    if 'meta' in obj_dict:
+      obj._meta = obj_dict['meta']
+
     return obj
 
   def __init__(self, obj_type, obj_id=None, obj_attributes=None):
@@ -173,6 +179,12 @@ class Object:
       return self._relationships
     return {}
 
+  @property
+  def meta(self):
+    if hasattr(self, '_meta'):
+      return self._meta
+    return {}
+
   def get(self, attr_name, default=None):
     """Returns an attribute by name.
 
@@ -207,4 +219,7 @@ class Object:
     if self.context_attributes:
       result['context_attributes'] = self.context_attributes
 
+    if self.meta:
+      result['meta'] = self.meta
+
     return result
